# -*- coding: utf-8 -*-
#
# Copyright 2009-2012 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#

"""Tests for the Ubuntu SSO GTK+ graphical interface."""

APP_NAME = u'I ♥ Ubuntu'
CAPTCHA_ID = u'test ñiña'
CAPTCHA_SOLUTION = u'william Byrd ñandú'
EMAIL = u'test@example.com'
EMAIL_TOKEN = u'B2P☺ gtf'
HELP_TEXT = u'☛ Lorem ipsum dolor sit amet, consectetur adipiscing elit. ' \
    'Nam sed lorem nibh. Suspendisse gravida nulla non nunc suscipit ' \
    'pulvinar ' \
    'tempus ut augue. Morbi consequat, ligula a elementum pretium, ' \
    'dolor nulla tempus metus, sed viverra nisi risus non velit.'
NAME = u'Juanito ☀ Pérez'
PASSWORD = u'h3lloWorld☑ '
PING_URL = u'http://localhost/ping-me/'
RESET_PASSWORD_TOKEN = u'8G5Wtq'
TC_URL = u'http://localhost/'
UNKNOWN_ERROR = u'Something went very wrong! ☹'
